# area4
Dividers in Python, the easy way!  Four different types.  (As seen on PyPI)

## Installing  
*You may install in one of the following ways:*  
* Through pip  
* Through requirements.txt  

### To install via pip  
To install via pip, open a terminal, and type the following command:  
```  
pip install area4  
```  
It should install.  

### To install via requirements.txt  
To use area4 as a dependency for your project, you can add the following line:  
```  
area4  
```  
You must have prior knowledge with using a requirements.txt file to take this path.  

## Using  
After you install the package (instructions above), you need to import it into any Python file that you will use it in.  You can do this by adding the following line to the top:  
```  
import area4  
```  
After doing so, you can use any of these methods to get a divider in your console:  

Just using plain print commands:  
```  
print(area4.divider1)  
print(area4.divider2)  
print(area4.divider3)  
print(area4.divider4)  
```  
Using functions:  
```  
div1()
div2()
div3()
div4()
```  
And if you want to you can check to make sure the library is working:  
```  
area4info()
```  
